@@ -1,13 +1,12 @@
 #!/bin/bash
 #=======================================================================
-# * Version: $Id: supp.sh,v 1.1 2015/07/01 10:49:27 nroche Exp $
 # * Project: MediaTex
 # * Module:  supp
 # *
 # * Unit test script for supp.c
 #
 # MediaTex is an Electronic Records Management System
-# Copyright (C) 2014 2015 Nicolas Roche
+# Copyright (C) 2014 2015 2016 Nicolas Roche
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -33,7 +32,7 @@ TEST=$(basename $0)
 TEST=${TEST%.sh}
 
 # run the unit test
-cp $CVSCLT/$MDTXUSER-coll1$EXTRFILE $CVSCLT/$MDTXUSER-coll2$EXTRFILE
+cp $GITCLT/$MDTXUSER-coll1$EXTRFILE $GITCLT/$MDTXUSER-coll2$EXTRFILE
 client/ut$TEST -d $srcdir/../misc >client/$TEST.out 2>&1
 
 # compare with the expected output
