@@ -26,5 +26,5 @@
 BINDIR=/usr/bin
 MDTX=${MDTX-mdtx}
 
-$BINDIR/mediatex -c $MDTX -swarning -ffile make >/dev/null
-$BINDIR/mediatex -c $MDTX -swarning -ffile motd >/etc/motd
+$BINDIR/mediatex -c $MDTX -swarning -p make >/dev/null
+$BINDIR/mediatex -c $MDTX -swarning -p motd >/etc/motd
