@@ -52,19 +52,23 @@ HTDOCS_configure_mdtx_apache2
     authz_core auth_digest authz_groupfile autoindex cgi env include \
     rewrite userdir setenvif ssl
 /usr/sbin/a2ensite default-ssl
+/usr/sbin/a2enconf mediatex
 /usr/sbin/invoke-rc.d rsyslog restart
 /sbin/ldconfig
 
 # mdtx config for apache
-/usr/sbin/a2enconf mediatex ${MEDIATEX#/}-$MDTX.conf >/dev/null
-/usr/sbin/invoke-rc.d apache2 restart
+/usr/sbin/a2enconf ${MEDIATEX#/}-$MDTX >/dev/null
 
-# script is not automatically installed for other instances than mdtx
+# init script is run at startup for mdtx instance
 if [ $MDTX = mdtx ]; then
     /usr/sbin/update-rc.d ${MEDIATEX#/}d defaults
     /usr/sbin/invoke-rc.d ${MEDIATEX#/}d restart $MDTX
 fi
 
 JAIL_bind # not needed but more confortable
+
+# restart apache
+/usr/sbin/invoke-rc.d apache2 restart
+
 Info "done"
 
