@@ -1,13 +1,12 @@
 #!/bin/bash
 #=======================================================================
-# * Version: $Id: log.sh,v 1.5 2015/08/09 13:20:34 nroche Exp $
 # * Project: MediaTex
 # * Module : script libs
 # *
 # * Provide log facilities
 #
 # MediaTex is an Electronic Records Management System
-# Copyright (C) 2014 2015 Nicolas Roche
+# Copyright (C) 2014 2015 2016 Nicolas Roche
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -79,6 +78,18 @@ Warning()
     Log "warn" "$1" ${2-1}
 }
 
+# print a notification on the standard error stream:
+# $1: message
+# $2: optional indirection number
+Notice()
+{
+    case ${LOG_SEVERITY-info} in
+	error|warning) return 0;;
+    esac
+
+    Log "notice" "$1" ${2-1}
+}
+
 # print an information message on the standard error stream:
 # $1: message
 # $2: optional indirection number
@@ -119,3 +130,5 @@ Debug()
 LOG_FILE=${MDTX_LOG_FILE-""}
 LOG_FACILITY=${MDTX_LOG_FACILITY-file}
 LOG_SEVERITY=${MDTX_LOG_SEVERITY_SCRIPT-info}
+
+Info "(script) LOG_SEVERITY = $LOG_SEVERITY"
