@@ -35,9 +35,10 @@ set -e
 
 Debug "new"
 [ $(id -u) -eq 0 ] || Error "need to be root"
-[ ! -z "$MDTX_MDTXUSER" ] || 
-Error "expect MDTX_MDTXUSER variable to be set by the environment"
+[ ! -z "$MDTX_MDTXUSER" ] || \
+    Error "expect MDTX_MDTXUSER variable to be set by the environment"
 [ ! -z $1 ] || Error "expect a label as first parameter"
+[ ! "$1" = "mdtx" ] || Error "collection cannot be labeled mdtx"
 
 SERV=$(echo $1 | cut -s -d "-" -f1)
 TMP=$(echo $1 | cut -d "-" -f2)
@@ -88,13 +89,8 @@ fi
 GIT_coll_checkout $USER $SERV $COLL $HOST
 HTDOCS_configure_coll_cgit $USER
 
-# BUG too ?
-# reload daemons as there configuration have changed
-/usr/sbin/invoke-rc.d apache2 reload
-
-# BUG (to remove when ACL will be implemented)
-#if [ $MDTX = mdtx ]; then
-#    /usr/sbin/invoke-rc.d ${MEDIATEX#/}d restart
-#fi
+# BUG ?
+# reload daemons as configuration has changed
+#/usr/sbin/invoke-rc.d apache2 reload
 
 Info "done"
