@@ -1,12 +1,11 @@
 /*=======================================================================
- * Version: $Id: commonHtml.c,v 1.10 2015/08/13 21:14:32 nroche Exp $
  * Project: MediaTeX
  * Module : commonHtml
 
 * HTML serializer common fonctions
 
 MediaTex is an Electronic Records Management System
-Copyright (C) 2014 2015 Nicolas Roche
+Copyright (C) 2014 2015 2016 Nicolas Roche
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -231,6 +230,48 @@ int getDocumentUri(char* buf, char* path, int id)
   return rc;
 }
 
+/*=======================================================================
+ * Function   : getArchiveScore
+ * Description: print score into buffer and return it
+ * Synopsis   : getArchiveScore(Archive* self) 
+ *              Archive* self: related archive
+ * Output     : char* buf = the static string buffer
+ =======================================================================*/
+char* getArchiveScore(Archive* self)
+{
+  static char score[8];
+
+  if (self->incInherency) {
+    sprintf(score, "(%s)", "---");
+  }
+  else {
+    sprintf(score, "(%.2f)", self->extractScore);
+  }
+
+  return score;
+}
+
+/*=======================================================================
+ * Function   : getContainerScore
+ * Description: print score into buffer and return it
+ * Synopsis   : getContainerScore(Container* self) 
+ *              Container* self: related container
+ * Output     : char* buf = the static string buffer
+ =======================================================================*/
+char* getContainerScore(Container* self)
+{
+  static char score[8];
+
+  if (self->incInherency) {
+    sprintf(score, "(%s)", "---");
+  }
+  else {
+    sprintf(score, "(%.2f)", self->score);
+  }
+
+  return score;
+}
+
 
 /*=======================================================================
  * Function   : serializeHtmlListBar
@@ -418,47 +459,9 @@ htmlAssoCarac(FILE* fd, AssoCarac* self)
 
 
 /*=======================================================================
- * Function   : getServerUrl
- * Description: get base url for a server
- * Synopsis   : int serializeHtmlCacheTop(Collection* coll)
- * Input      : Server* server
- *              char* url: an allocated string
- *              char* txt: text to cat at the end of the url
- * Output     : TRUE on success
- =======================================================================*/
-int getServerUrl(Server* server, char* txt, char* url)
-{
-  int rc = FALSE;
-
-  checkServer(server);
-  if (!server->wwwPort) {
-    logMain(LOG_WARNING, "no www port define for this server");
-    server->wwwPort = WWW_PORT;
-  }
-  
-  if (server->wwwPort == 443) {
-    if (sprintf(url, "https://%s/~%s%s", 
-		 server->host, server->user, txt) <= 0) goto error;
-  }
-  else {
-    if (sprintf(url, "https://%s:%i/~%s%s",
-  		 server->host, server->wwwPort, server->user, txt) <= 0)
-      goto error;
-  }
-  
-  rc = TRUE;
- error:
-  if (!rc) {
-    logMain(LOG_ERR, "getServerUrl fails");
-  }
-  return rc;
-}
-
-
-/*=======================================================================
- * Function   : serializeHtmlCacheTop
+ * Function   : serializeHtmlCacheHeader
  * Description: This template will be used by apache SSI
- * Synopsis   : int serializeHtmlCacheTop(Collection* coll)
+ * Synopsis   : int serializeHtmlCacheHeader(Collection* coll)
  * Input      : Collection* coll: input collection
  * Output     : TRUE on success
  =======================================================================*/
@@ -470,9 +473,8 @@ serializeHtmlCacheHeader(Collection* coll)
   Server *server = 0;
   RGIT* curr = 0;
   char* path = 0;
-  char url[512];
   FILE* fd = stdout; 
-
+  char url[512];
 
   if (!(self = coll->serverTree)) goto error;
   if (!(path = createString(coll->htmlDir))) goto error;
@@ -484,7 +486,7 @@ serializeHtmlCacheHeader(Collection* coll)
   }  
 
   if (!htmlMainHead(fd, _("Cache"))) goto error;
-  if (!htmlLeftPageHead(fd, _("cache"))) goto error;
+  if (!htmlLeftPageHead(fd, "cache")) goto error;
 
   if (!isEmptyRing(self->servers)) {
     if (!rgSort(self->servers, cmpServer)) goto error;
@@ -492,8 +494,8 @@ serializeHtmlCacheHeader(Collection* coll)
 
     rgRewind(self->servers);
     while ((server = rgNext_r(self->servers, &curr))) {
-      if (!getServerUrl(server, "/cache", url)) goto error;
-      
+      strcpy(url, server->url);
+      strcpy(url + strlen(url), "/cache"); 
       htmlLiOpen(fd);
       htmlLink(fd, 0, url, server->host);
       htmlLiClose(fd);      
@@ -501,11 +503,8 @@ serializeHtmlCacheHeader(Collection* coll)
     htmlUlClose(fd);
   }
   
-  // master url (other are relatives ones)
-  if (!getServerUrl(coll->serverTree->master, "", url)) goto error;
-  
   if (!htmlLeftPageTail(fd)) goto error;
-  if (!htmlRightHead(fd, url)) goto error;
+  if (!htmlRightHead(fd)) goto error;
   
   if (!env.dryRun) {
     fclose(fd);
@@ -523,9 +522,9 @@ serializeHtmlCacheHeader(Collection* coll)
 
 
 /*=======================================================================
- * Function   : serializeHtmlCgiTop
+ * Function   : serializeHtmlCgiHeader
  * Description: This template will be used by apache SSI
- * Synopsis   : int serializeHtmlCgiTop(Collection* coll)
+ * Synopsis   : int serializeHtmlCgiHeader(Collection* coll)
  * Input      : Collection* coll: input collection
  * Output     : TRUE on success
  =======================================================================*/
@@ -538,24 +537,25 @@ serializeHtmlCgiHeader(Collection* coll)
   Server *server = 0;
   RGIT* curr = 0;
   char* path = 0;
-  char url1[512];
-  char url2[512];
+  char url[512];
   FILE* fd = stdout; 
 
-  if (!(conf = getConfiguration())) goto error;
-
-  if (!(self = coll->serverTree)) goto error;
   if (!(path = createString(coll->htmlDir))) goto error;
   if (!(path = catString(path, "/cgiHeader.shtml"))) goto error;
   logMain(LOG_DEBUG, "serialize %s", path);
+  if (!(conf = getConfiguration())) goto error;
+  if (!(self = coll->serverTree)) goto error;
+  if (!getLocalHost(coll)) goto error;
+  
   if (!env.dryRun && (fd = fopen(path, "w")) == 0) {
     logMain(LOG_ERR, "fdopen %s fails: %s", path, strerror(errno)); 
     goto error;
   }  
 
-  if (!getServerUrl(getLocalHost(coll), "", url1)) goto error;
-  if (!htmlMainHeadBasic(fd, _("Cache"), url1)) goto error;
-  if (!htmlLeftPageHeadBasic(fd, _("cache"), url1)) goto error;
+  if (!htmlMainHeadBasic(fd, _("Cache"), coll->localhost->url))
+    goto error;
+  if (!htmlLeftPageHeadBasic(fd, "cache", coll->localhost->url))
+    goto error;
 
   if (!isEmptyRing(self->servers)) {
     if (!rgSort(self->servers, cmpServer)) goto error;
@@ -563,18 +563,17 @@ serializeHtmlCgiHeader(Collection* coll)
 
     rgRewind(self->servers);
     while ((server = rgNext_r(self->servers, &curr))) {
-      if (!getServerUrl(server, "/cache", url2)) goto error;
-      
+      strcpy(url, server->url);
+      strcpy(url + strlen(url), "/cache"); 
       htmlLiOpen(fd);
-      htmlLink(fd, 0, url2, server->host);
+      htmlLink(fd, 0, url, server->host);
       htmlLiClose(fd);      
     }
     htmlUlClose(fd);
   }
   
-  if (!getServerUrl(coll->serverTree->master, "", url2)) goto error;
   if (!htmlLeftPageTail(fd)) goto error;
-  if (!htmlRightHeadBasic(fd, url2, url1)) goto error;
+  if (!htmlRightHeadBasic(fd, coll->localhost->url)) goto error;
   
   if (!env.dryRun) {
     fclose(fd);
@@ -590,6 +589,78 @@ serializeHtmlCgiHeader(Collection* coll)
   return rc;
 }
 
+
+/*=======================================================================
+ * Function   : serializeHtmlGitHeader
+ * Description: This template will be used by cgit
+ * Synopsis   : int serializeHtmlGitHeader(Collection* coll)
+ * Input      : Collection* coll: input collection
+ * Output     : TRUE on success
+ =======================================================================*/
+static int 
+serializeHtmlGitHeader(Collection* coll)
+{ 
+  int rc = TRUE;
+  Configuration* conf = 0;
+  ServerTree* self = 0;
+  //Server *server = 0;
+  //RGIT* curr = 0;
+  char* path = 0;
+  //char url[512];
+  FILE* fd = stdout; 
+
+  if (!(path = createString(coll->htmlDir))) goto error;
+  if (!(path = catString(path, "/gitHeader.html"))) goto error;
+  logMain(LOG_DEBUG, "serialize %s", path);
+  if (!(conf = getConfiguration())) goto error;
+  if (!(self = coll->serverTree)) goto error;
+  if (!getLocalHost(coll)) goto error;
+  
+  if (!env.dryRun && (fd = fopen(path, "w")) == 0) {
+    logMain(LOG_ERR, "fdopen %s fails: %s", path, strerror(errno)); 
+    goto error;
+  }  
+
+  if (!htmlMainHeadBasic(fd, _("Version"), coll->localhost->url))
+    goto error;
+  if (!htmlLeftPageHeadBasic(fd, "cgi/cgit.cgi/.git/",
+			     coll->localhost->url))
+    goto error;
+
+  /*
+  if (!isEmptyRing(self->servers)) {
+    if (!rgSort(self->servers, cmpServer)) goto error;
+    htmlUlOpen(fd);
+
+    rgRewind(self->servers);
+    while ((server = rgNext_r(self->servers, &curr))) {
+      strcpy(url, server->url);
+      strcpy(url + strlen(url), "/cgi/cgit.cgi/.git/"); 
+      htmlLiOpen(fd);
+      htmlLink(fd, 0, url, server->host);
+      htmlLiClose(fd);      
+    }
+    htmlUlClose(fd);
+  }
+  */
+  
+  if (!htmlLeftPageTail(fd)) goto error;
+  if (!htmlRightHeadBasic(fd, coll->localhost->url)) goto error;
+  
+  if (!env.dryRun) {
+    fclose(fd);
+  } else {
+    fflush(stdout);
+  }
+  rc = TRUE;
+ error:
+  if (!rc) {
+    logMain(LOG_ERR, "serializeHtmlGitHeader fails");
+  }
+  path = destroyString(path);
+  return rc;
+}
+
 
 /*=======================================================================
  * Function   : serializeHtmlAllBottom
@@ -643,6 +714,62 @@ serializeHtmlFooter(Collection* coll)
   return rc;
 }
 
+
+/*=======================================================================
+ * Function   : serializeHtmlCacheHtaccess
+ * Description: Set apache SSI variables
+ * Synopsis   : int serializeHtmlCacheHtaccess(Collection* coll)
+ * Input      : Collection* coll: input collection
+ * Output     : TRUE on success
+ =======================================================================*/
+static int 
+serializeHtmlCacheHtaccess(Collection* coll)
+{ 
+  int rc = TRUE;
+  ServerTree* self = 0;
+  char* path = 0;
+  FILE* fd = stdout; 
+
+  if (!(self = coll->serverTree)) goto error;
+  if (!(path = createString(coll->cacheDir))) goto error;
+  if (!(path = catString(path, "/.htaccess"))) goto error;
+  logMain(LOG_DEBUG, "serialize %s", path);
+  if (!env.dryRun && (fd = fopen(path, "w")) == 0) {
+    logMain(LOG_ERR, "fdopen %s fails: %s", path, strerror(errno)); 
+    goto error;
+  }  
+
+  if (!fprintf(fd,
+	       "# fancy index for cache\n"
+	       "Options +Indexes\n"
+	       "SetEnv HOME /~%s\n"
+	       "HeaderName"
+	       " /mediatex/%s/home/%s/public_html/cacheHeader.shtml\n"
+	       "ReadmeName"
+	       " /mediatex/%s/home/%s/public_html/footer.html\n"
+	       "\n"
+	       "# login/password\n"
+	       "Require env NO_AUTH\n"
+	       "Require group cache\n",
+	       coll->user,
+	       env.confLabel, coll->user,
+	       env.confLabel, coll->user))
+      goto error;
+
+  if (!env.dryRun) {
+    fclose(fd);
+  } else {
+    fflush(stdout);
+  }
+  rc = TRUE;
+ error:
+  if (!rc) {
+    logMain(LOG_ERR, "serializeHtmlCacheHtaccess fails");
+  }
+  path = destroyString(path);
+  return rc;
+}
+
 
 /*=======================================================================
  * Function   : serializeHtmlCache
@@ -661,7 +788,9 @@ serializeHtmlCache(Collection* coll)
 
   if (!serializeHtmlCacheHeader(coll)) goto error;
   if (!serializeHtmlCgiHeader(coll)) goto error;
+  if (!serializeHtmlGitHeader(coll)) goto error;
   if (!serializeHtmlFooter(coll)) goto error;
+  if (!serializeHtmlCacheHtaccess(coll)) goto error;
 
   rc = TRUE;
  error:
