@@ -39,6 +39,7 @@ int mdtxMake(char* label)
   Collection* coll = 0;
   int uid = getuid();
   int n = 0;
+  char progBarLabel[MAX_SIZE_COLL+6];
 
   checkLabel(label);
   if (!(coll = mdtxGetCollection(label))) goto error;
@@ -52,22 +53,22 @@ int mdtxMake(char* label)
   env.progBar.max = 0;
   n = avl_count(coll->archives);
   env.progBar.max += n + 2*n / MAX_INDEX_PER_PAGE;
-  logMain(LOG_INFO, "estimate %i steps for archives", env.progBar.max);
+  logMain(LOG_DEBUG, "estimate %i steps for archives", env.progBar.max);
   n = avl_count(coll->catalogTree->documents);
   env.progBar.max += n + 2*n / MAX_INDEX_PER_PAGE;
   n = avl_count(coll->catalogTree->humans);
   env.progBar.max += n + 2*n / MAX_INDEX_PER_PAGE;
-  logMain(LOG_INFO, "estimate %i steps for all", env.progBar.max);
+  logMain(LOG_DEBUG, "estimate %i steps for all", env.progBar.max);
 
-  logMain(LOG_INFO, "html");
   if (!becomeUser(env.confLabel, TRUE)) goto error2;
-  startProgBar("make");
+  sprintf(progBarLabel, "make %s", label);
+  startProgBar(progBarLabel);
   if (!serializeHtmlCache(coll)) goto error3;
   if (!serializeHtmlIndex(coll)) goto error3;
   if (!serializeHtmlScore(coll)) goto error3;
   stopProgBar();
-  logMain(LOG_INFO, "steps: %lli / %lli", env.progBar.cur, env.progBar.max);
-  logMain(LOG_INFO, "ending");
+  logMain(LOG_DEBUG, "done: steps %lli / %lli", 
+	  env.progBar.cur, env.progBar.max);
 
   rc = TRUE;
  error3:
@@ -111,24 +112,23 @@ int mdtxUpgradePlus(char* label)
  * Author     : Nicolas ROCHE
  * modif      : 2013/10/23
  * Description: Upload + upgrade
- * Synopsis   : int mdtxUploadPlus(char* label, char* path)
+ * Synopsis   : int mdtxUploadPlus(char* label, char* catalog,
+ *                                 char* extract, RG* upFiles)
  * Input      : char* label = collection to pre-process
  *              char* catalog: catalog metadata file to upload
  *              char* extract: extract metadata file to upload
- *              char* file: data to upload
- *              char* targetPath: where to copy data into the cache
+ *              RG* upFiles: ring or UploadFile* ; data to upload
  * Output     : TRUE on success
  =======================================================================*/
-int mdtxUploadPlus(char* label, char* catalog, char* extract, 
-		   char* file, char* targetPath)
+int mdtxUploadPlus(char* label, char* catalog, char* extract, RG* upFiles)
 {
   int rc = FALSE;
 
   checkLabel(label);
-  if (!mdtxUpload(label, catalog, extract, file, targetPath)) 
-    goto error;
-
+  
+  if (!mdtxUpload(label, catalog, extract, upFiles)) goto error;
   if (!mdtxUpgrade(label)) goto error;
+  
   rc = TRUE;
  error:
   if (!rc) {
@@ -142,24 +142,24 @@ int mdtxUploadPlus(char* label, char* catalog, char* extract,
  * Author     : Nicolas ROCHE
  * modif      : 2013/10/23
  * Description: Upload + upgrade + make
- * Synopsis   : int mdtxUploadPlusPlus(char* label, char* path)
+ * Synopsis   : int mdtxUploadPlusPlus(char* label, char* catalog,
+ *                                     char* extract, RG* upFiles)
  * Input      : char* label = collection to pre-process
  *              char* catalog: catalog metadata file to upload
  *              char* extract: extract metadata file to upload
- *              char* file: data to upload
- *              char* targetPath: where to copy data into the cache
+ *              RG* upFiles: ring or UploadFile* ; data to upload
  * Output     : TRUE on success
  =======================================================================*/
 int mdtxUploadPlusPlus(char* label, char* catalog, char* extract, 
-		   char* file, char* targetPath)
+		       RG* upFiles)
 {
   int rc = FALSE;
 
   checkLabel(label);
-  if (!mdtxUploadPlus(label, catalog, extract, file, targetPath))
-    goto error;
-
+  
+  if (!mdtxUploadPlus(label, catalog, extract, upFiles)) goto error;
   if (!mdtxMake(label)) goto error;
+  
   rc = TRUE;
  error:
   if (!rc) {
@@ -183,10 +183,12 @@ mdtxClean(char* label)
   Configuration* conf = 0;
   //Collection* coll = 0;
   char* argv[3] = {0, 0, 0};
+  int isAllowed = 0;
 
   logMain(LOG_DEBUG, "del a collection");
 
-  if (!allowedUser(env.confLabel)) goto error;
+  if (!allowedUser(env.confLabel, &isAllowed, 0)) goto error;
+  if (!isAllowed) goto error;
   if (!(conf = getConfiguration())) goto error;
 
   argv[0] = createString(conf->scriptsDir);
@@ -459,6 +461,7 @@ mdtxSu(char* label)
   char* home = 0;
   char* user = 0;
   LogSeverity* tmpSev =  env.logHandler->severity[LOG_SCRIPT];
+  int isAllowed = 0;
   
   logMain(LOG_DEBUG, "mdtxSu %s", label?label:"");
 
@@ -482,7 +485,8 @@ mdtxSu(char* label)
 
   if (!env.noRegression && !env.dryRun) {
     if (setenv("HOME", home, 1) == -1) goto error;
-    if (!allowedUser(user)) goto error;
+    if (!allowedUser(user, &isAllowed, 0)) goto error;
+    if (!isAllowed) goto error;
     
     // do not close stdout! else we loose id and groups.
     env.logHandler->severity[LOG_SCRIPT] = LogSeverities+7;
