@@ -273,8 +273,7 @@ int loadRecords(Collection* coll)
   destroyRecordTree(coll->cacheTree->recordTree);
   coll->cacheTree->recordTree = tree;
   coll->cacheTree->recordTree->messageType = DISK;
-  for (node = coll->cacheTree->recordTree->records->head;
-       node; node = node->next) {
+  for (node = tree->records->head; node; node = node->next) {
     record = node->item;
     if (!addCacheEntry(coll, record)) goto error;
   }
@@ -379,7 +378,7 @@ loadCvsFiles(Collection* coll, int fileIdx)
     if (access(path, R_OK)) break;
     if (!parser(coll, path)) goto error;
   }
-  while (++i < 100);
+  while (++i < 1000);
   coll->fileState[fileIdx] = LOADED;
 
   // load last addon
@@ -540,6 +539,9 @@ loadCollectionNbSteps(Collection* coll, int collFiles)
     }    
   }
 
+  // add 3%
+  env.progBar.max *= 1.03;
+
   if (env.progBar.max > 0) {
     logCommon(LOG_INFO, "estimate %i steps for load", env.progBar.max);
   }
@@ -564,10 +566,11 @@ int
 loadCollection(Collection* coll, int collFiles)
 {
   int rc = FALSE;
+  char progBarLabel[MAX_SIZE_COLL+6];
 
   checkCollection(coll);
   logCommon(LOG_DEBUG, "load %s collection (%s)", 
-	  coll->label, strCF(collFiles));
+	    coll->label, strCF(collFiles));
 
   // force catalog to use archives from extract (assert no ophanes)
   if (collFiles & CTLG) collFiles |= EXTR;
@@ -578,18 +581,20 @@ loadCollection(Collection* coll, int collFiles)
     if (!callCommit(coll->user, "manual user edition")) goto error;
     if (!env.noGitPullPush) {
       if (coll->toUpdate && collFiles & (CTLG | EXTR | SERV)) {
+	logMain(LOG_INFO, "Git pull %s collection", coll->label);
 	if (callPull(coll->user)) coll->toUpdate = FALSE;
       }
     }
   }
 
   if (!loadCollectionNbSteps(coll, collFiles)) goto error;
-  if (env.progBar.max > 0) { // else nothing to do
-    logCommon(LOG_INFO, "parse %s collection (%s)", 
-	      coll->label, strCF(collFiles));
+  if (env.progBar.max > 0) {
+    logMain(LOG_INFO, "parse %s collection (%s)", 
+	    coll->label, strCF(collFiles));
   }
 
-  startProgBar("load");
+  sprintf(progBarLabel, "load %s", coll->label);
+  startProgBar(progBarLabel);
   if (!collectionLoop(coll, collFiles, loadColl)) goto error;
   stopProgBar();
 
@@ -929,19 +934,21 @@ saveCollection(Collection* coll, int collFiles)
 {
   int rc = FALSE;
   Configuration* conf = 0;
+  char progBarLabel[MAX_SIZE_COLL+6];
 
   checkCollection(coll);
   logCommon(LOG_DEBUG, "save %s collection (%s)", 
-	  coll->label, strCF(collFiles));
+	    coll->label, strCF(collFiles));
 
   if (!(conf = getConfiguration())) goto error;
   if (!saveCollectionNbSteps(coll, collFiles)) goto error;
   if (env.progBar.max > 0) { // else nothing to do
-    logCommon(LOG_DEBUG, "serialize  %s collection (%s)", 
+    logMain(LOG_INFO, "serialize  %s collection (%s)", 
 	      coll->label, strCF(collFiles));
   }
 
-  startProgBar("save");
+  sprintf(progBarLabel, "save %s", coll->label);
+  startProgBar(progBarLabel);
   if (!collectionLoop(coll, collFiles, saveColl)) goto error;
   stopProgBar();
   logCommon(LOG_INFO, "steps: %lli / %lli", 
@@ -951,6 +958,7 @@ saveCollection(Collection* coll, int collFiles)
   if (coll->toCommit && !env.noGit) {
     if (!callCommit(coll->user, 0)) goto error;
     if (!env.noGitPullPush) {
+      logMain(LOG_INFO, "Git push %s collection", coll->label);
       if (callPush(coll->user)) {
 	conf->toHup = TRUE;
 	coll->toCommit = FALSE;
@@ -1081,6 +1089,9 @@ diseaseColl(Collection* coll, int i)
   else {
     logCommon(LOG_INFO, "do not disease %s collection (%s)",
 	      coll->label, strCF(1<<i));
+    if (coll->fileState[i] == MODIFIED) {
+      logCommon(LOG_DEBUG, "... as modified");
+    }
     if (coll->fileState[i] != LOADED) {
       logCommon(LOG_DEBUG, "... as not loaded");
     }
@@ -1233,11 +1244,13 @@ Support* mdtxGetSupport(char* label)
 {
   Support* rc = 0;
   Support* supp = 0;
-
+  int isAllowed = 0;
+  
   checkLabel(label);  
   logCommon(LOG_DEBUG, "get %s support", label);
 
-  if (!allowedUser(env.confLabel)) goto error;
+  if (!allowedUser(env.confLabel, &isAllowed, 0)) goto error;
+  if (!isAllowed) goto error;
   if (!loadConfiguration(SUPP)) goto error;
   if (!(supp = getSupport(label))) goto error;
 
@@ -1264,10 +1277,12 @@ clientLoop(int (*callback)(char*))
   Configuration* conf = 0;
   Collection* coll = 0;
   RGIT* curr = 0;
-
+  int isAllowed = 0;
+  
   logCommon(LOG_DEBUG, "loop on all collections");
 
-  if (!allowedUser(env.confLabel)) goto error;
+  if (!allowedUser(env.confLabel, &isAllowed, 0)) goto error;
+  if (!isAllowed) goto error;
 
   // for all collection
   if (!loadConfiguration(CFG)) goto error;
@@ -1304,11 +1319,13 @@ serverLoop(int (*callback)(Collection*))
   Configuration* conf = 0;
   Collection* coll = 0;
   RGIT* curr = 0;
-
+  int isAllowed = 0;
+  
   logCommon(LOG_DEBUG, "loop on all collections (2)");
 
-  if (!allowedUser(env.confLabel)) goto error;
-
+  if (!allowedUser(env.confLabel, &isAllowed, 0)) goto error;
+  if (!isAllowed) goto error;
+  
   // for all collection
   if (!loadConfiguration(CFG)) goto error;
   conf = getConfiguration();
