@@ -57,7 +57,7 @@ mdtxShmRead(void *buffer, int shmSize, void* arg)
   ShmParam* param = (ShmParam*)arg;
 
   strncpy(param->buf, (char*)buffer, shmSize);
-  param->buf[MDTX_SHM_BUFF_SIZE] = (char)0;
+  param->buf[REG_SHM_BUFF_SIZE] = (char)0;
 }
   
 /*=======================================================================
@@ -67,16 +67,16 @@ mdtxShmRead(void *buffer, int shmSize, void* arg)
  * Synopsis   : void mdtxShmEnable(void *buffer, void* arg)
  * Input      : void *buffer: SHM buffer
  *              int shmSize: SHM size
- *              void* arg:    input from pointer on ShmParam 
+ *              void* arg:    input from pointer on ShmParam
  * Output     : N/A
  =======================================================================*/
-static void 
-mdtxShmEnable(void *buffer, int shmSize, void* arg) 
+static void
+mdtxShmEnable(void *buffer, int shmSize, void* arg)
 {
   ShmParam* param = (ShmParam*)arg;
   (void) shmSize;
 
-  ((char*)buffer)[param->flag] = MDTX_QUERY;
+  ((char*)buffer)[param->flag] = REG_QUERY;
 }
 
 /*=======================================================================
@@ -86,16 +86,17 @@ mdtxShmEnable(void *buffer, int shmSize, void* arg)
  * Synopsis   : void mdtxShmDisable(void *buffer, void* arg)
  * Input      : void *buffer: SHM buffer
  *              int shmSize: SHM size
- *              void* arg:    input from pointer on ShmParam 
+ *              void* arg:    input from pointer on ShmParam
  * Output     : N/A
+ * Note       : never used
  =======================================================================*/
-void 
-mdtxShmDisable(void *buffer, int shmSize, void* arg) 
+void
+mdtxShmDisable(void *buffer, int shmSize, void* arg)
 {
   ShmParam* param = (ShmParam*)arg;
   (void) shmSize;
 
-  ((char*)buffer)[param->flag] = MDTX_DONE;
+  ((char*)buffer)[param->flag] = REG_DONE;
 }
 
 /*=======================================================================
@@ -105,16 +106,17 @@ mdtxShmDisable(void *buffer, int shmSize, void* arg)
  * Synopsis   : void mdtxShmDisable(void *buffer, void* arg)
  * Input      : void *buffer: SHM buffer
  *              int shmSize: SHM size
- *              void* arg:    input from pointer on ShmParam 
+ *              void* arg:    input from pointer on ShmParam
  * Output     : N/A
+ * Note       : only used by init test
  =======================================================================*/
-void 
-mdtxShmError(void *buffer, int shmSize, void* arg) 
+void
+mdtxShmError(void *buffer, int shmSize, void* arg)
 {
   ShmParam* param = (ShmParam*)arg;
   (void) shmSize;
 
-  ((char*)buffer)[param->flag] = MDTX_ERROR;
+  ((char*)buffer)[param->flag] = REG_ERROR;
 }
 
 /*=======================================================================
@@ -127,12 +129,14 @@ mdtxShmError(void *buffer, int shmSize, void* arg)
 int 
 mdtxShmInitialize()
 {
-  static char* buffer = "0000\0";
   ShmParam param;
 
-  strncpy(param.buf, buffer, MDTX_SHM_BUFF_SIZE);
-  logCommon(LOG_NOTICE, "Initialise SHM using %s conf file", env.confLabel);
-  return shmWrite(getConfiguration()->confFile, MDTX_SHM_BUFF_SIZE, 
+  logCommon(LOG_NOTICE, "Initialise SHM using %s conf file", 
+	    env.confLabel);
+
+  memset(param.buf, '0', REG_SHM_BUFF_SIZE);
+  param.buf[REG_SHM_BUFF_SIZE] = 0; 
+  return shmWrite(getConfiguration()->confFile, REG_SHM_BUFF_SIZE, 
 		  mdtxShmCopy, (void*)&param);
 }
 
@@ -146,7 +150,7 @@ mdtxShmInitialize()
 int
 mdtxShmFree()
 {
-  return shmFree(getConfiguration()->confFile, MDTX_SHM_BUFF_SIZE);
+  return shmFree(getConfiguration()->confFile, REG_SHM_BUFF_SIZE);
 }
 
 /*=======================================================================
@@ -185,7 +189,7 @@ mdtxAsyncSignal(int signal)
     goto error;
   }
 
-  // send SIGUSR1 to daemon
+  // send signal (HUP or SIGUSR1) to daemon
   logCommon(LOG_INFO, "sending signal %i to %i", signal, pid);
 
   if (kill(pid, signal) == -1) {
@@ -229,21 +233,22 @@ int mdtxSyncSignal(int flag)
   }
 
   // Read register
-  if (!shmRead(conf->confFile, MDTX_SHM_BUFF_SIZE, 
+  if (!shmRead(conf->confFile, REG_SHM_BUFF_SIZE, 
 	       mdtxShmRead, (void*)&param))
       goto error;
 
   // Do no set if register is already set
-  if (param.buf[flag] == MDTX_QUERY) goto quit;
+  if (param.buf[flag] == REG_QUERY || param.buf[flag] == REG_PENDING) 
+    goto wait;
 
-  // Set register
+  // Set registers
   logCommon(LOG_INFO, "setting %i register", flag);
   param.flag = flag;
-  if (!shmWrite(conf->confFile, MDTX_SHM_BUFF_SIZE, 
+  if (!shmWrite(conf->confFile, REG_SHM_BUFF_SIZE, 
 		mdtxShmEnable, (void*)&param))
     goto error;
 
- quit:
+ wait:
   // Send SIGUSR1 signal to the daemon
   if (!mdtxAsyncSignal(SIGUSR1)) goto error;
 
@@ -251,13 +256,14 @@ int mdtxSyncSignal(int flag)
   logCommon(LOG_INFO, "waiting for %i register unset", flag);
   do {
     usleep(200000);
-    rc = shmRead(conf->confFile, MDTX_SHM_BUFF_SIZE, 
+    rc = shmRead(conf->confFile, REG_SHM_BUFF_SIZE, 
 		 mdtxShmRead, (void*)&param);
   }
-  while (rc && (param.buf[flag] == MDTX_QUERY));
-
+  while (rc && (param.buf[flag] == REG_QUERY ||
+		param.buf[flag] == REG_PENDING));
+  
   rc = TRUE;
-  if (param.buf[flag] != MDTX_DONE) {
+  if (param.buf[flag] != REG_DONE) {
     logCommon(LOG_WARNING, "server fails to perform your query");
   }
  error:
