@@ -1,12 +1,11 @@
 /*=======================================================================
- * Version: $Id: upgrade.c,v 1.15 2015/10/11 21:11:13 nroche Exp $
  * Project: MediaTeX
  * Module : upgrade
  *
  * Manage servers.txt upgrade from mediatex.conf and supports.txt
 
  MediaTex is an Electronic Records Management System
- Copyright (C) 2014 2015 Nicolas Roche
+ Copyright (C) 2014 2015 2016 Nicolas Roche
  
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -27,9 +26,9 @@
 #include <dirent.h>    // scandir
 
 /*=======================================================================
- * Function   : checkSupport 
+ * Function   : doCheckSupport 
  * Description: Do checksums on an available support
- * Synopsis   : int checkSupport(Support *supp, char* path)
+ * Synopsis   : int soCheckSupport(Support *supp, char* path)
  * Input      : Support *supp = the support object
  *              char* path = the device that host the support
  * Output     : TRUE on success
@@ -117,11 +116,13 @@ doCheckSupport(Support *supp, char* path)
     rc = FALSE;
   }
 
-  if (!rc && !isSupportFile(supp)) {
+  if (!rc) {
     logMain(LOG_WARNING, "please manualy check \"%s\" support", supp->name);
-    logMain(LOG_WARNING, "either this is not \"%s\" support at %s", 
-	    supp->name, path);
-    logMain(LOG_WARNING, "or maybe the \"%s\" support is obsolete", 
+    if (!isSupportFile(supp)) {
+      logMain(LOG_WARNING, "either this is not \"%s\" support at %s, or", 
+	      supp->name, path);
+    }
+    logMain(LOG_WARNING, "maybe the \"%s\" support is obsolete", 
 	    supp->name);
     goto error;
   }
@@ -260,9 +261,9 @@ scoreSupport(Support* supp, ScoreParam *p)
 
 
 /*=======================================================================
- * Function   : scoreLocaleImages
+ * Function   : scoreLocalImages
  * Description: Compute ISO score on local server
- * Synopsis   : int scoreLocaleImages(Collection* coll)
+ * Synopsis   : int scoreLocalImages(Collection* coll)
  * Input      : Collection* coll = collection to upgrade
  *              Server* server = the local server
  * Output     : TRUE on success 
@@ -353,135 +354,6 @@ scoreLocalImages(Collection* coll)
   return rc;
 }
 
-
-/*=======================================================================
- * Function   : serializeCvsRootClientFiles
- * Description: Serialize the CVS/Root files.
- * Synopsis   : static int serializeCvsRootClientFiles(Collection* coll)
- * Input      : Collection* coll = what to serialize
- *              char* dirpath = directory whe is the Root file
- * Output     : TRUE on success
- =======================================================================*/
-static int 
-serializeCvsRootClientFile(Collection* coll, char* dirpath)
-{ 
-  int rc = FALSE;
-  char* path = 0;
-  FILE* fd = stdout; 
-  ServerTree* self = 0;
-  mode_t mask;
-
-  mask = umask(0117);
-  checkCollection(coll);
-  if (!(self = coll->serverTree)) goto error;
-  checkServer(self->master);
-  logCommon(LOG_DEBUG, "serialize CVS/Root files");
-
-  if (!(path = createString(dirpath)) ||
-      !(path = catString(path, "/")) ||
-      !(path = catString(path, "Root"))) goto error;
-      
-  // output file
-  if (!env.dryRun) {
-    if ((fd = fopen(path, "w")) == 0) {
-      logCommon(LOG_ERR, "fdopen %s fails: %s", path, strerror(errno)); 
-      goto error;
-    }
-  }
-      
-  fprintf(fd, ":ext:%s@%s:/var/lib/cvsroot\n",
-	  self->master->user, self->master->host);
-  fprintf(fd, "# This file is managed by MediaTeX software.\n");
-
-  fflush(fd);
-  rc = TRUE;  
- error:  
-  if (fd != stdout && fclose(fd)) {
-    logCommon(LOG_ERR, "fclose fails: %s", strerror(errno));
-    rc = FALSE;
-  }
-  if (!rc) {
-    logCommon(LOG_ERR, "serializeCvsRootClientFile fails");
-  }
-  umask(mask);
-  path = destroyString(path);
-  return rc;
-}
-
-
-/*=======================================================================
- * Function   : scanCvsClientDirectory
- * Description: Serialize the CVS/Root files.
- * Synopsis   : static int scanCvsClientDirectory(Collection* coll,
- *                                                char* path)
- * Input      : Collection* coll = context
- *              char* path = directory to scan
- * Output     : TRUE on success
- =======================================================================*/
-int 
-scanCvsClientDirectory(Collection* coll, char* path) 
-{
-  int rc = FALSE;
-  ServerTree* self = 0;
-  struct dirent** entries;
-  struct dirent* entry;
-  int nbEntries = 0;
-  int n = 0;
-  char* subdir = 0;
-
-  if (!(self = coll->serverTree)) goto error;
-  checkServer(self->master);
-  logCommon(LOG_DEBUG, "scaning CVS directory: %s", path);
-
-  entries = 0;
-  if ((nbEntries 
-       = scandir(path, &entries, 0, alphasort)) == -1) {
-    logCommon(LOG_ERR, "scandir fails on %s: %s", path, strerror(errno));
-    goto error;
-  }
-
-  for (n=0; n<nbEntries; ++n) {
-    entry = entries[n];
-    if (!strcmp(entry->d_name, ".")) continue;
-    if (!strcmp(entry->d_name, "..")) continue;
-    
-    switch (entry->d_type) {
-
-    case DT_DIR: 
-      if (!(subdir = createString(path)) ||
-	  !(subdir = catString(subdir, "/")) ||
-	  !(subdir = catString(subdir, entry->d_name)))	goto error;
-
-      if (!strcmp(entry->d_name, "CVS")) {
-	if (!serializeCvsRootClientFile(coll, subdir)) goto error;
-      }
-      else {
-	if (!scanCvsClientDirectory(coll, subdir)) goto error;
-      }
-
-      default: 
-	break;
-      }   
-      
-    subdir = destroyString(subdir);
-  }
-
-  rc = TRUE;
- error:
-  if (!rc) {
-    logCommon(LOG_ERR, "scanCvsClientDirectory fails");
-  }
-  if (entries) {
-    for (n=0; n<nbEntries; ++n) {
-      remind(entries[n]);
-      free(entries[n]);
-    }
-    remind(entries);
-    free(entries);
-  }
-  return rc;
-}
-
 /*=======================================================================
  * Function   : upgradeCollection
  * Description: Upgrade servers.txt
@@ -490,7 +362,9 @@ scanCvsClientDirectory(Collection* coll, char* path)
  * Output     : TRUE on success 
 
  * Note       : Must only be call by client (nor server or cgi).
- *              This function do almost all the consistency job:
+ *              And should only be called by  openClose.c::loadColl().
+ *
+ *              Do almost all the consistency job:
  *              - re-compute the local image's score
  *              - update own configuration values into servers.txt
  *              - update ssh configuration files (config, key and auth)
@@ -509,6 +383,7 @@ upgradeCollection(Collection* coll)
   RG* ring = 0;
   RGIT* curr = 0;
   int isMaster = FALSE;
+  char url[256];
 
   checkCollection(coll);
   logCommon(LOG_DEBUG, "upgradeCollection %s", coll->label);
@@ -526,7 +401,7 @@ upgradeCollection(Collection* coll)
   strncpy(localhost->host, conf->host, MAX_SIZE_HOST);
   localhost->mdtxPort = conf->mdtxPort;
   localhost->sshPort = conf->sshPort;
-  localhost->wwwPort = conf->wwwPort;
+  //localhost->wwwPort = conf->wwwPort;
   if (!(localhost->comment = createString(conf->comment))) goto error;
   if (!(localhost->userKey = createString(coll->userKey))) goto error;
   if (!(localhost->hostKey = createString(conf->hostKey))) goto error;
@@ -557,7 +432,6 @@ upgradeCollection(Collection* coll)
   }
 
   coll->localhost = localhost;
-  localhost = 0;
 
   // add local images to serverTree
   if (!scoreLocalImages(coll)) goto error;
@@ -571,7 +445,7 @@ upgradeCollection(Collection* coll)
   // if master change his collection key, we need
   // to look first to the master prefix into mdtx.conf file
   if (isMaster) {
-    coll->serverTree->master = coll->localhost;
+    coll->serverTree->master = localhost;
   }
 
   // else we trust the servers.txt file
@@ -581,6 +455,10 @@ upgradeCollection(Collection* coll)
     goto error;
   }
 
+  // uprgade www port on servers.txt
+  localhost->wwwPort =
+    coll->serverTree->doHttps ? conf->httpsPort : conf->httpPort;
+  
   // upgrade master ids on collection stanza into configuration
   // note: this is also valuable for master server
   // conf.coll := server.master
@@ -607,10 +485,13 @@ upgradeCollection(Collection* coll)
   // upgrade SSH settings (using servers)
   if (!env.noRegression && !upgradeSshConfiguration(coll)) goto error;
 
-  // upgrade CVS/Root files (using conf.coll)
-  if (!env.noRegression && !scanCvsClientDirectory(coll, coll->cvsDir)) 
-    goto error;
-
+  // upgrade GIT settings
+  if (sprintf(url, "ssh://%s@%s:/var/lib/gitbare/%s",
+	      coll->serverTree->master->user,
+	      coll->serverTree->master->host,
+	      coll->serverTree->master->user) <= 0) goto error;
+  if (!callUpgrade(coll->user, coll->userFingerPrint, url)) goto error;
+  
   rc = TRUE;
 error:
   if (!rc) {
@@ -621,6 +502,54 @@ error:
   return rc;
 }
 
+/*=======================================================================
+ * Function   : computeUrls
+ * Description: Update all server's url
+ * Synopsis   : int computeUrls(Collection* coll)
+ * Input      : Collection* coll = collection to update              
+ * Output     : TRUE on success 
+ * Note       : this is done out from upgrade() as cgi and server only
+ *              read servers.txt but do not upgrade
+ =======================================================================*/
+int 
+computeUrls(Collection* coll)
+{
+  int rc = FALSE;
+  Server* server = 0;
+  RGIT* curr = 0;
+  char url[512];
+
+  checkCollection(coll);
+  logCommon(LOG_DEBUG, "computeUrls %s", coll->label);
+
+  while ((server = rgNext_r(coll->serverTree->servers, &curr))) {
+    
+    // add port into the url if not the default one
+    if ((coll->serverTree->doHttps && server->wwwPort == 443) ||
+	(!coll->serverTree->doHttps && server->wwwPort == 80)) {
+      if (sprintf(url, "http%s://%s/~%s",
+		  coll->serverTree->doHttps?"s":"",
+		  server->host, server->user) <= 0) goto error;
+    }
+    else {
+      if (sprintf(url, "http%s://%s:%i/~%s",
+		  coll->serverTree->doHttps?"s":"",
+		  server->host, server->wwwPort, server->user) <= 0)
+	goto error;
+      
+    }
+    if (!(server->url = createString(url))) goto error;
+  }
+  
+  rc = TRUE;
+error:
+  if (!rc) {
+    logCommon(LOG_ERR, "computeUrls fails");
+  }
+  return rc;
+}
+
+
 /* Local Variables: */
 /* mode: c */
 /* mode: font-lock */
