@@ -51,75 +51,85 @@ signalJob(void* arg)
 {
   int me = taskSignalNumber;
   Configuration* conf = 0;
-  Collection* coll = 0;
   long int rc = FALSE;
-  int loop = FALSE;
+  int rc2 = REG_DONE;
+  int i = 0;
+  int j = 0;
+  char mask[REG_SHM_BUFF_SIZE];
   ShmParam param;
-  int rc3 = MDTX_DONE;
-  RGIT* curr = 0;
+  
+  struct job {
+    int reg;
+    int (*function)(Collection*);
+    char *name; // only for logs
+  };
+
+  static struct job jobs[9] = {
+    {REG_SAVEMD5, saveCache, "SAVEMD5"},
+    {REG_EXTRACT, extractArchives, "EXTRACT"},
+    {REG_NOTIFY, sendRemoteNotify, "NOTIFY"},
+    {REG_PURGE, purgeCache, "PURGE"},
+    {REG_CLEAN, cleanCache, "CLEAN"},
+    {REG_TRIM, trimCache, "TRIM"},
+    {REG_SCAN, scanCache, "SCAN"},
+    {REG_QUICKSCAN, quickScanCache, "QUICK SCAN"},
+    {REG_STATUS, statusCache, "STATUS"}
+  };
 
   (void) arg;
   logMain(LOG_DEBUG, "signalJob: %i", me);
   if (!(conf = getConfiguration())) goto error;
+  memset(mask, 0, REG_SHM_BUFF_SIZE);
 
-  do {
-    int rc2 = MDTX_DONE;
-    loop = FALSE;
-    if (!shmRead(conf->confFile, MDTX_SHM_BUFF_SIZE,
-		 mdtxShmRead, (void*)&param))
-      goto error;
-    
-    if (param.buf[MDTX_SAVEMD5] == MDTX_QUERY) {
-      logMain(LOG_NOTICE, "signalJob %i: SAVEMD5", me);
-
-      // force writing
-      while ((coll = rgNext_r(conf->collections, &curr))) {
-	coll->fileState[iCACH] = MODIFIED;
-      }
-      if (!serverSaveAll()) rc2 = MDTX_ERROR;
-      param.flag = MDTX_SAVEMD5;
-      loop = TRUE;
-      goto quit;
+  if (!shmRead(conf->confFile, REG_SHM_BUFF_SIZE,
+	       mdtxShmRead, (void*)&param))
+    goto error;
+   
+  // loop on jobs (as several jobs may be wanted here)
+  for (i=0; i<9 ; ++i) {
+    if (param.buf[jobs[i].reg] != REG_QUERY) continue;
+  
+    logMain(LOG_NOTICE, "signalJob %i: %s", me, jobs[i].name);
+    mask[jobs[i].reg] = 1;
+      
+    // "purge" do more than "clean", and so...
+    switch (jobs[i].reg) {
+    case REG_PURGE:
+      mask[REG_CLEAN] = 1;
+    case REG_CLEAN:
+      mask[REG_TRIM] = 1;
+    case REG_TRIM:
+    case REG_SCAN:
+      mask[REG_QUICKSCAN] = 1;
+    case REG_QUICKSCAN:
+      mask[REG_STATUS] = 1;
     }
-    
-    if (param.buf[MDTX_EXTRACT] == MDTX_QUERY) {
-      logMain(LOG_NOTICE, "signalJob %i: EXTRACT", me);
-      if (!serverLoop(extractArchives)) rc2 = MDTX_ERROR;
-      param.flag = MDTX_EXTRACT;
-      loop = TRUE;
-      goto quit;
+      
+    // mark job as pending
+    for (j=0; j<REG_SHM_BUFF_SIZE; ++j) {
+      if (mask[j]) param.buf[j] = REG_PENDING;
     }
-    
-    if (param.buf[MDTX_NOTIFY] == MDTX_QUERY) {
-      logMain(LOG_NOTICE, "signalJob %i: NOTIFY", me);
-      if (!serverLoop(sendRemoteNotify)) rc2 = MDTX_ERROR;
-      param.flag = MDTX_NOTIFY;
-      loop = TRUE;
-      goto quit;
+    if (!shmWrite(conf->confFile, REG_SHM_BUFF_SIZE,
+		  mdtxShmCopy, (void*)&param)) goto error;
+      
+    // do the jobs
+    if (jobs[i].reg == REG_STATUS) {
+      memoryStatus(LOG_NOTICE, __FILE__, __LINE__);
     }
-
-    /* if (param.buf[MDTX_DELIVER] == MDTX_QUERY) { */
-    /*   logMain(LOG_NOTICE, "signalJob %i: DELIVER", me); */
-    /*   if (!serverLoop(deliverMails)) rc2 = MDTX_ERROR; */
-    /*   param.flag = MDTX_DELIVER; */
-    /*   loop = TRUE; */
-    /*   goto quit; */
-    /* } */
-
-  quit:
-    if (loop) {
-      if (!shmWrite(conf->confFile, MDTX_SHM_BUFF_SIZE,
-		    (rc2 == MDTX_DONE)?mdtxShmDisable:mdtxShmError,
-		    (void*)&param))
-	goto error;
+    if (!serverLoop(jobs[i].function)) rc2 = REG_ERROR;
+      
+    // mark job as done
+    for (j=0; j<REG_SHM_BUFF_SIZE; ++j) {
+      if (mask[j]) param.buf[j] = rc2;
     }
-    if (rc2 == MDTX_ERROR) rc3 = MDTX_ERROR;
-  } while (loop);
+    if (!shmWrite(conf->confFile, REG_SHM_BUFF_SIZE,
+		  mdtxShmCopy, (void*)&param)) goto error;
+  }
 
   rc = TRUE;
  error:
   if (rc) {
-    if (rc3) {
+    if (rc2 == REG_DONE) {
       logMain(LOG_NOTICE, "signalJob %i: success", me);
     } else {
       logMain(LOG_ERR, "signalJob %i: fails", me);
@@ -144,29 +154,33 @@ int
 hupManager()
 {
   int rc = FALSE;
-  
-  if (!serverSaveAll()) {
-    logMain(LOG_ERR, "Fails to save md5sums before reloading");
-    goto error;
-  }
+  Configuration* conf = 0;
+  Collection* coll = 0;
+  RGIT* curr = 0;
 
+  if (!serverSaveAll()) goto error;
   freeConfiguration();
-
-  if (!loadConfiguration(CFG)) {
-    logMain(LOG_ERR, "HUP: fails to reload configuration");
-    goto error;
-  }
+  if (!loadConfiguration(CFG)) goto error;
+  if (!expandConfiguration()) goto error;
   
-  if (!quickScanAll()) {
-    logMain(LOG_ERR, "HUP: fails to scan caches");
-    goto error;
+  // for all collection
+  conf = getConfiguration();
+  if (conf->collections) {
+    while ((coll = rgNext_r(conf->collections, &curr))) {
+      if (!loadCache(coll)) goto error;
+    }
   }
 
+  // where to call it ? no use here because of freeConfiguration()
+  //if (!cleanCacheTree(coll)) goto error;
+
   rc = TRUE;
-  logMain(LOG_NOTICE, "daemon is HUP");
  error:
   if (!rc) {
-    logMain(LOG_ERR, "daemon fails to update: exiting");
+    logMain(LOG_ERR, "daemon HUP fails: exiting");
+  }
+  else {
+    logMain(LOG_NOTICE, "daemon is HUP");
   }
   return rc;
 }
