@@ -518,7 +518,7 @@ static const yytype_uint8 yytranslate[] =
 static const yytype_uint8 yyrline[] =
 {
        0,   116,   116,   119,   120,   123,   129,   130,   132,   147,
-     151,   155,   158,   159,   161,   195
+     151,   155,   158,   159,   161,   200
 };
 #endif
 
@@ -1382,20 +1382,25 @@ yyreduce:
 	    MAX_SIZE_SIZE, (long long int)(yyvsp[0].record)->archive->size, 
 	    (yyvsp[0].record)->extra?(yyvsp[0].record)->extra:"");
 
-   if (!avl_insert(recordTree->records, (yyvsp[0].record))) {
-     logParser(LOG_ERR, "cannot add record (already there?)");
-     // RQ: YYABORT will close the socket, do YYERROR close it ?
-     YYERROR;
+  if (getRecordType((yyvsp[0].record)) == MALLOC_SUPPLY) {
+    logParser(LOG_WARNING, "ignore malloc record");
+    if (!delRecord(recordTree->collection, (yyvsp[0].record))) YYERROR;
+  }
+  else {
+    if (!avl_insert(recordTree->records, (yyvsp[0].record))) {
+      logParser(LOG_ERR, "cannot add record (already there?)");
+      // RQ: YYABORT will close the socket, do YYERROR close it ?
+      YYERROR;
+    }
   }
 
   (yyvsp[0].record) = 0;
-
 }
-#line 1395 "parser/recordFile.tab.c" /* yacc.c:1646  */
+#line 1400 "parser/recordFile.tab.c" /* yacc.c:1646  */
     break;
 
   case 15:
-#line 196 "parser/recordFile.y" /* yacc.c:1646  */
+#line 201 "parser/recordFile.y" /* yacc.c:1646  */
     {
   Server* server = 0;
   Archive* archive = 0;
@@ -1413,20 +1418,19 @@ yyreduce:
     YYERROR;
   }
 
-  if (!(archive = addArchive(recordTree->collection, (yyvsp[-2].hash), (yyvsp[-1].size)))) 
-    YYERROR;
-
+  if (!(archive = addArchive(recordTree->collection, (yyvsp[-2].hash), (yyvsp[-1].size)))) YYERROR;
   if (!(extra = createString((yyvsp[0].string)))) YYERROR;
+
   if (!((yyval.record) = 
 	addRecord(recordTree->collection, server, archive, (yyvsp[-5].type), extra)))
     YYERROR;
   (yyval.record)->date = (yyvsp[-4].time);
 }
-#line 1426 "parser/recordFile.tab.c" /* yacc.c:1646  */
+#line 1430 "parser/recordFile.tab.c" /* yacc.c:1646  */
     break;
 
 
-#line 1430 "parser/recordFile.tab.c" /* yacc.c:1646  */
+#line 1434 "parser/recordFile.tab.c" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1654,7 +1658,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 223 "parser/recordFile.y" /* yacc.c:1906  */
+#line 227 "parser/recordFile.y" /* yacc.c:1906  */
 
       /* epilogue: =====================================================*/
 
