@@ -771,24 +771,18 @@ cacheSet(ExtractData* data, Record* record,
   // (rename do not honor default target acl)
   logMain(LOG_INFO, "move %s to %s", 
 	  absoluteExtractPath, absoluteCachePath);
-  /*
-  if (rename(absoluteExtractPath, absoluteCachePath)) {
-    logMain(LOG_ERR, "rename fails: %s", strerror(errno));
-    goto error;
-  }
-  */
   if (!extractCp(absoluteExtractPath, absoluteCachePath)) goto error;
   if (unlink(absoluteExtractPath)) {
     logMain(LOG_ERR, "unlink fails: %s", strerror(errno));
     goto error;
   }
 
-  // toggle !malloc record to local-supply...
+  // toggle !malloc record to local-supply
   relativeCachePath = absoluteCachePath + strlen(coll->cacheDir) + 1;
   record->extra = destroyString(record->extra);
   if (!(record->extra = createString(relativeCachePath))) goto error;
 
-  // ...and add a toKepp on the new extracted archive
+  // add a toKepp on the new extracted archive
   if (!extractAddToKeep(data, record->archive)) goto error;
 
   logMain(LOG_NOTICE, "%s:%lli extracted", 
@@ -1023,7 +1017,8 @@ extractFromAsso(ExtractData* data, FromAsso* asso)
  *              FALSE on error
  * Note       : Recursive calls to extract container(s)
  =======================================================================*/
-int extractContainer(ExtractData* data, Container* container)
+int
+extractContainer(ExtractData* data, Container* container)
 {
   int rc = FALSE;
   Archive* archive = 0;
@@ -1087,7 +1082,8 @@ int extractContainer(ExtractData* data, Container* container)
  *              int rc: FALSE on error
  * Note       : Recursive call
  =======================================================================*/
-int extractArchive(ExtractData* data, Archive* archive, int doCp)
+int
+extractArchive(ExtractData* data, Archive* archive, int doCp)
 {
   int rc = FALSE;
   Collection* coll = 0;
@@ -1231,7 +1227,8 @@ int extractArchive(ExtractData* data, Archive* archive, int doCp)
  * Input      : Collection* coll
  * Output     : TRUE on success
  =======================================================================*/
-int extractArchives(Collection* coll)
+int
+extractArchives(Collection* coll)
 {
   int rc = FALSE;
   int rc2 = FALSE;
